--- allow_origins: - '*' allow_xss: false alt_top_banner: '' auto_reload: false auto_reload_interval: 5.0 code: '' mimetype: text/html no_header: true no_navheader: true require_method: - GET - POST require_permissions: - view_nvr resource_timestamp: 1690502472006620 resource_type: page setupcode: "from kaithem.api.devices import all_devices\r\nfrom kaithem.src import\ \ theming" streaming_response: false template_engine: mako theme_css_url: '' ---
%if 'controls' in kwargs:
%else:
%endif